"""Make a compressed .tar archive
of the .zarr files generated by
running src/scripts/prep_song_data.py.
The nox session 'prep-pcb-dataset'
runs that script, and this script is
run by the session 'tar-pcb-dataset'.
"""
import pathlib
import shutil

import rich.progress

RESULTS_ROOT = pathlib.Path('./results')
PREPD_SONG_DATA_ROOT = RESULTS_ROOT / 'pcb_data/song_data'
ZARR_SUBDIRS = [
    dir_ for dir_ in PREPD_SONG_DATA_ROOT.iterdir()
    if dir_.is_dir() and dir_.name.endswith('.zarr')
]

# --- main script ----

for zarr_subdir in rich.progress.track(ZARR_SUBDIRS):
    rich.print(
        f'Making archive from {zarr_subdir}'
    )
    shutil.make_archive(
        base_name=zarr_subdir,
        format='tar',
        root_dir='.',
        base_dir=zarr_subdir,
    )


rich.print(
    f"Finished making archive from {PREPD_SONG_DATA_ROOT}."
)
